@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2020 Lance Edgar
+#  Copyright © 2010-2022 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -40,6 +40,8 @@ class CustomerView(APIMasterView):
     model_class = model.Customer
     collection_url_prefix = '/customers'
     object_url_prefix = '/customer'
+    supports_autocomplete = True
+    autocomplete_fieldname = 'name'
 
     def normalize(self, customer):
         return {
