@@ -332,7 +332,7 @@ class Form(object):
 
     def __init__(self, fields=None, schema=None, request=None, readonly=False, readonly_fields=[],
                  model_instance=None, model_class=None, appstruct=UNSPECIFIED, nodes={}, enums={}, labels={},
-                 assume_local_times=False, renderers=None,
+                 assume_local_times=False, renderers=None, renderer_kwargs={},
                  hidden={}, widgets={}, defaults={}, validators={}, required={}, helptext={}, focus_spec=None,
                  action_url=None, cancel_url=None, use_buefy=None, component='tailbone-form',
                  vuejs_field_converters={},
@@ -361,6 +361,7 @@ class Form(object):
             self.renderers = self.make_renderers()
         else:
             self.renderers = renderers or {}
+        self.renderer_kwargs = renderer_kwargs or {}
         self.hidden = hidden or {}
         self.widgets = widgets or {}
         self.defaults = defaults or {}
@@ -374,6 +375,9 @@ class Form(object):
         self.component = component
         self.vuejs_field_converters = vuejs_field_converters or {}
 
+    def __iter__(self):
+        return iter(self.fields)
+
     @property
     def component_studly(self):
         words = self.component.split('-')
@@ -447,6 +451,9 @@ class Form(object):
     def append(self, field):
         self.fields.append(field)
 
+    def insert(self, index, field):
+        self.fields.insert(index, field)
+
     def insert_before(self, field, newfield):
         self.fields.insert_before(field, newfield)
 
@@ -654,6 +661,22 @@ class Form(object):
         else:
             self.renderers[key] = renderer
 
+    def add_renderer_kwargs(self, key, kwargs):
+        self.renderer_kwargs.setdefault(key, {}).update(kwargs)
+
+    def get_renderer_kwargs(self, key):
+        return self.renderer_kwargs.get(key, {})
+
+    def set_renderer_kwargs(self, key, kwargs):
+        self.renderer_kwargs[key] = kwargs
+
+    def set_input_handler(self, key, value):
+        """
+        Convenience method to assign "input handler" callback code for
+        the given field.
+        """
+        self.add_renderer_kwargs(key, {'input_handler': value})
+
     def set_hidden(self, key, hidden=True):
         self.hidden[key] = hidden
 
@@ -715,7 +738,9 @@ class Form(object):
         """
         Render the help text for the given field.
         """
-        return self.helptext[key]
+        text = self.helptext[key]
+        text = text.replace('"', '&quot;')
+        return HTML.literal(text)
 
     def set_vuejs_field_converter(self, field, converter):
         self.vuejs_field_converters[field] = converter
@@ -850,6 +875,59 @@ class Form(object):
             return False
         return True
 
+    def render_buefy_field(self, fieldname, bfield_attrs={}):
+        """
+        Render the given field in a Buefy-compatible way.  Note that
+        this is meant to render *editable* fields, i.e. showing a
+        widget, unless the field input is hidden.  In other words it's
+        not for "readonly" fields.
+        """
+        dform = self.make_deform_form()
+        field = dform[fieldname]
+
+        if self.field_visible(fieldname):
+
+            # these attrs will be for the <b-field> (*not* the widget)
+            attrs = {
+                ':horizontal': 'true',
+                'label': self.get_label(fieldname),
+            }
+
+            # add some magic for file input fields
+            if isinstance(field.schema.typ, deform.FileData):
+                attrs['class_'] = 'file'
+
+            # show helptext if present
+            if self.has_helptext(fieldname):
+                attrs['message'] = self.render_helptext(fieldname)
+
+            # show errors if present
+            error_messages = self.get_error_messages(field)
+            if error_messages:
+                attrs.update({
+                    'type': 'is-danger',
+                    # ':message': self.messages_json(error_messages),
+                    ':message': error_messages,
+                })
+
+            # merge anything caller provided
+            attrs.update(bfield_attrs)
+
+            # render the field widget or whatever
+            html = field.serialize(use_buefy=True,
+                                   **self.get_renderer_kwargs(fieldname))
+            # TODO: why do we not get HTML literal from serialize() ?
+            html = HTML.literal(html)
+
+            # and finally wrap it all in a <b-field>
+            return HTML.tag('b-field', c=[html], **attrs)
+
+        else: # hidden field
+
+            # can just do normal thing for these
+            # TODO: again, why does serialize() not return literal?
+            return HTML.literal(field.serialize())
+
     def render_field_readonly(self, field_name, **kwargs):
         """
         Render the given field completely, but in read-only fashion.
@@ -1044,12 +1122,22 @@ class FieldList(list):
     """
 
     def insert_before(self, field, newfield):
-        i = self.index(field)
-        self.insert(i, newfield)
+        if field in self:
+            i = self.index(field)
+            self.insert(i, newfield)
+        else:
+            log.warning("field '%s' not found, will append new field: %s",
+                        field, newfield)
+            self.append(newfield)
 
     def insert_after(self, field, newfield):
-        i = self.index(field)
-        self.insert(i + 1, newfield)
+        if field in self:
+            i = self.index(field)
+            self.insert(i + 1, newfield)
+        else:
+            log.warning("field '%s' not found, will append new field: %s",
+                        field, newfield)
+            self.append(newfield)
 
 
 @colander.deferred
