@@ -34,7 +34,6 @@ from six.moves import urllib
 import sqlalchemy as sa
 from sqlalchemy import orm
 
-from rattail.db import api
 from rattail.db.types import GPCType
 from rattail.util import prettify, pretty_boolean, pretty_quantity, pretty_hours
 from rattail.time import localtime
@@ -78,7 +77,7 @@ class Grid(object):
                  joiners={}, filterable=False, filters={}, use_byte_string_filters=False,
                  searchable={},
                  sortable=False, sorters={}, default_sortkey=None, default_sortdir='asc',
-                 pageable=False, default_pagesize=20, default_page=1,
+                 pageable=False, default_pagesize=None, default_page=1,
                  checkboxes=False, checked=None, check_handler=None, check_all_handler=None,
                  clicking_row_checks_box=False, click_handlers=None,
                  main_actions=[], more_actions=[], delete_speedbump=False,
@@ -596,7 +595,16 @@ class Grid(object):
         """
         class_ = getattr(model_property, 'class_', self.model_class)
         column = getattr(class_, model_property.key)
-        return lambda q, d: q.order_by(getattr(column, d)())
+
+        def sorter(query, direction):
+            # TODO: this seems hacky..normally we expect a true query
+            # of course, but in some cases it may be a list instead.
+            # if so then we can't actually sort
+            if isinstance(query, list):
+                return query
+            return query.order_by(getattr(column, direction)())
+
+        return sorter
 
     def make_simple_sorter(self, key, foldcase=False):
         """
@@ -609,6 +617,19 @@ class Grid(object):
             keyfunc = lambda v: v[key]
         return lambda q, d: sorted(q, key=keyfunc, reverse=d == 'desc')
 
+    def get_default_pagesize(self):
+        if self.default_pagesize:
+            return self.default_pagesize
+
+        pagesize = self.request.rattail_config.getint('tailbone',
+                                                      'grid.default_pagesize',
+                                                      default=0)
+        if pagesize:
+            return pagesize
+
+        options = self.get_pagesize_options()
+        return options[0]
+
     def load_settings(self, store=True):
         """
         Load current/effective settings for the grid, from the request query
@@ -626,7 +647,7 @@ class Grid(object):
             settings['sortkey'] = self.default_sortkey
             settings['sortdir'] = self.default_sortdir
         if self.pageable:
-            settings['pagesize'] = self.default_pagesize
+            settings['pagesize'] = self.get_default_pagesize()
             settings['page'] = self.default_page
         if self.filterable:
             for filtr in self.iter_filters():
@@ -721,7 +742,8 @@ class Grid(object):
 
         # User defaults should have all or nothing, so just check one key.
         key = 'tailbone.{}.grid.{}.sortkey'.format(user.uuid, self.key)
-        return api.get_setting(session, key) is not None
+        app = self.request.rattail_config.get_app()
+        return app.get_setting(Session(), key) is not None
 
     def apply_user_defaults(self, settings):
         """
@@ -729,7 +751,8 @@ class Grid(object):
         """
         def merge(key, normalize=lambda v: v):
             skey = 'tailbone.{}.grid.{}.{}'.format(self.request.user.uuid, self.key, key)
-            value = api.get_setting(Session(), skey)
+            app = self.request.rattail_config.get_app()
+            value = app.get_setting(Session(), skey)
             settings[key] = normalize(value)
 
         if self.filterable:
@@ -907,7 +930,8 @@ class Grid(object):
         def persist(key, value=lambda k: settings[k]):
             if to == 'defaults':
                 skey = 'tailbone.{}.grid.{}.{}'.format(self.request.user.uuid, self.key, key)
-                api.save_setting(Session(), skey, value(key))
+                app = self.request.rattail_config.get_app()
+                app.save_setting(Session(), skey, value(key))
             else: # to == session
                 skey = 'grid.{}.{}'.format(self.key, key)
                 self.request.session[skey] = value(key)
@@ -984,6 +1008,16 @@ class Grid(object):
         return pager
 
     def make_pager(self, data):
+
+        # TODO: this seems hacky..normally we expect `data` to be a
+        # query of course, but in some cases it may be a list instead.
+        # if so then we can't use ORM pager
+        if isinstance(data, list):
+            import paginate
+            return paginate.Page(data,
+                                 items_per_page=self.pagesize,
+                                 page=self.page)
+
         return SqlalchemyOrmPage(data,
                                  items_per_page=self.pagesize,
                                  page=self.page,
@@ -1458,6 +1492,12 @@ class GridAction(object):
             return self.url(row, i)
         return self.url
 
+    def render_icon(self):
+        """
+        Render the HTML snippet for the action link icon.
+        """
+        return HTML.tag('i', class_='fas fa-{}'.format(self.icon))
+
     def render_label(self):
         """
         Render the label "text" within the actions column of a grid
