@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2021 Lance Edgar
+#  Copyright © 2010-2022 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -87,7 +87,7 @@ class AuthenticationView(View):
             # Store current URL in session, for smarter redirect after login.
             self.request.session['next_url'] = self.request.current_route_url()
             next_url = self.request.route_url('login')
-        self.request.session.flash(msg, allow_duplicate=False)
+        self.request.session.flash(msg, 'warning', allow_duplicate=False)
         return self.redirect(next_url)
 
     def login(self, **kwargs):
