@@ -45,7 +45,7 @@ from sqlalchemy import orm
 from rattail.db import model, Session as RattailSession
 from rattail.db.util import short_session
 from rattail.threads import Thread
-from rattail.util import load_object, prettify, simple_error
+from rattail.util import prettify, simple_error
 from rattail.progress import SocketProgress
 
 import colander
@@ -102,6 +102,7 @@ class BatchMasterView(MasterView):
         'id',
         'description',
         'notes',
+        'params',
         'created',
         'created_by',
         'rowcount',
@@ -141,12 +142,13 @@ class BatchMasterView(MasterView):
         ``batch_key`` attribute of the main batch model class.
         """
         # first try to figure out if config defines a factory class
+        app = rattail_config.get_app()
         model_class = cls.get_model_class()
         batch_key = model_class.batch_key
-        spec = rattail_config.get('rattail.batch', '{}.handler'.format(batch_key),
-                                  default=cls.default_handler_spec)
-        if spec: # yep, so use that
-            return load_object(spec)
+        handler = app.get_batch_handler(batch_key,
+                                        default=cls.default_handler_spec)
+        if handler:
+            return handler.__class__
 
         # fall back to whatever class was defined statically
         return cls.batch_handler_class
@@ -960,7 +962,13 @@ class BatchMasterView(MasterView):
 
         # run command in subprocess
         log.debug("launching command in subprocess: %s", cmd)
-        subprocess.check_call(cmd)
+        try:
+            subprocess.check_output(cmd, stderr=subprocess.PIPE)
+        except subprocess.CalledProcessError as error:
+            log.warning("command failed with exit code %s!  output was:",
+                        error.returncode)
+            log.warning(error.stderr.decode('utf_8'))
+            raise
 
     def action_subprocess_thread(self, key, port, username, handler_action, progress, **kwargs):
         """
@@ -1055,15 +1063,15 @@ class BatchMasterView(MasterView):
         user = session.query(model.User).get(user_uuid)
         try:
             self.handler.do_populate(batch, user, progress=progress)
+            session.flush()
         except Exception as error:
             session.rollback()
-            log.warning("batch population failed: %s", batch, exc_info=True)
+            log.exception("population failed for batch %s: %s", batch.uuid, batch)
             session.close()
             if progress:
                 progress.session.load()
                 progress.session['error'] = True
-                progress.session['error_msg'] = "Batch population failed: {}".format(
-                    simple_error(error))
+                progress.session['error_msg'] = simple_error(error)
                 progress.session.save()
             return
 
@@ -1112,6 +1120,7 @@ class BatchMasterView(MasterView):
         cognizer = session.query(model.User).get(user_uuid) if user_uuid else None
         try:
             self.refresh_data(session, batch, cognizer, progress=progress)
+            session.flush()
         except Exception as error:
             session.rollback()
             log.warning("refreshing data for batch failed: {}".format(batch), exc_info=True)
