@@ -471,16 +471,6 @@ class InventoryBatchView(BatchMasterView):
             if not self.allow_cases(row.batch):
                 f.set_readonly('cases')
 
-    def render_upc(self, row, field):
-        upc = row.upc
-        if not upc:
-            return ""
-        text = upc.pretty()
-        if row.product_uuid:
-            url = self.request.route_url('products.view', uuid=row.product_uuid)
-            return tags.link_to(text, url)
-        return text
-
     @classmethod
     def defaults(cls, config):
         cls._batch_defaults(config)
