@@ -83,6 +83,7 @@ class VendorCatalogView(FileBatchMasterView):
         'vendor',
         'future',
         'effective',
+        'cache_products',
         'params',
         'description',
         'notes',
@@ -148,10 +149,33 @@ class VendorCatalogView(FileBatchMasterView):
 
     def configure_grid(self, g):
         super(VendorCatalogView, self).configure_grid(g)
-        g.joiners['vendor'] = lambda q: q.join(model.Vendor)
-        g.filters['vendor'] = g.make_filter('vendor', model.Vendor.name,
-                                            default_active=True, default_verb='contains')
-        g.sorters['vendor'] = g.make_sorter(model.Vendor.name)
+        model = self.model
+
+        # nb. this batch has vendor_id and vendor_name fields, but in
+        # practice they aren't used much and normally just the vendor
+        # proper is set.  so we remove simple filters and add the
+        # custom one for (referenced) vendor name
+        g.remove_filter('vendor_id')
+        g.remove_filter('vendor_name')
+        g.set_joiner('vendor', lambda q: q.join(model.Vendor))
+        g.set_filter('vendor', model.Vendor.name,
+                     default_active=True,
+                     default_verb='contains')
+        # and this is the same thing we are showing as grid column
+        g.set_sorter('vendor', model.Vendor.name)
+
+        # preferred filters
+        g.set_filters_sequence([
+            'id',
+            'vendor',
+            'description',
+            'executed',
+            'created',
+            'filename',
+            'future',
+            'effective',
+            'notes',
+        ])
 
         g.set_link('vendor')
         g.set_link('filename')
@@ -185,7 +209,17 @@ class VendorCatalogView(FileBatchMasterView):
         if self.creating and 'vendor' in f:
             f.replace('vendor', 'vendor_uuid')
             f.set_label('vendor_uuid', "Vendor")
+
+            # should we use dropdown or autocomplete?  note that if
+            # autocomplete is to be used, we also must make sure we
+            # have an autocomplete url registered
             use_dropdown = vendor_handler.choice_uses_dropdown()
+            if not use_dropdown:
+                try:
+                    vendors_url = self.request.route_url('vendors.autocomplete')
+                except KeyError:
+                    use_dropdown = True
+
             if use_dropdown:
                 vendors = self.Session.query(model.Vendor)\
                                       .order_by(model.Vendor.id)
@@ -202,7 +236,6 @@ class VendorCatalogView(FileBatchMasterView):
                             self.request.POST['vendor_uuid'])
                         if vendor:
                             vendor_display = six.text_type(vendor)
-                vendors_url = self.request.route_url('vendors.autocomplete')
                 f.set_widget('vendor_uuid',
                              forms.widgets.JQueryAutocompleteWidget(
                                  field_display=vendor_display,
@@ -223,6 +256,15 @@ class VendorCatalogView(FileBatchMasterView):
             f.remove('future',
                      'effective')
 
+        if self.creating:
+            f.set_node('cache_products', colander.Boolean())
+            f.set_type('cache_products', 'boolean')
+            f.set_helptext('cache_products',
+                           "If set, will pre-cache all products for quicker "
+                           "lookups when loading the catalog.")
+        else:
+            f.remove('cache_products')
+
     def render_parser_key(self, batch, field):
         key = getattr(batch, field)
         if not key:
@@ -282,6 +324,11 @@ class VendorCatalogView(FileBatchMasterView):
             kwargs['effective'] = batch.effective
         return kwargs
 
+    def save_create_form(self, form):
+        batch = super(VendorCatalogView, self).save_create_form(form)
+        batch.set_param('cache_products', form.validated['cache_products'])
+        return batch
+
     def configure_row_grid(self, g):
         super(VendorCatalogView, self).configure_row_grid(g)
         batch = self.get_instance()
@@ -305,6 +352,11 @@ class VendorCatalogView(FileBatchMasterView):
         g.set_label('unit_cost', "New Cost")
         g.set_label('unit_cost_diff', "Diff. $")
 
+        g.set_link('upc')
+        g.set_link('brand')
+        g.set_link('description')
+        g.set_link('vendor_code')
+
     def row_grid_extra_class(self, row, i):
         if row.status_code == row.STATUS_PRODUCT_NOT_FOUND:
             return 'warning'
@@ -384,20 +436,30 @@ class VendorCatalogView(FileBatchMasterView):
 
     def configure_remove_settings(self):
         super(VendorCatalogView, self).configure_remove_settings()
-        model = self.model
+        app = self.get_rattail_app()
+
         names = [
             'rattail.vendors.supported_catalog_parsers',
             'tailbone.batch.vendorcatalog.supported_parsers', # deprecated
         ]
 
-        Session().query(model.Setting)\
-                 .filter(model.Setting.name.in_(names))\
-                 .delete(synchronize_session=False)
+        # nb. using thread-local session here; we do not use
+        # self.Session b/c it may not point to Rattail
+        session = Session()
+        for name in names:
+            app.delete_setting(session, name)
 
 
 # TODO: deprecate / remove this
 VendorCatalogsView = VendorCatalogView
 
 
-def includeme(config):
+def defaults(config, **kwargs):
+    base = globals()
+
+    VendorCatalogView = kwargs.get('VendorCatalogView', base['VendorCatalogView'])
     VendorCatalogView.defaults(config)
+
+
+def includeme(config):
+    defaults(config)
