@@ -47,9 +47,11 @@ class CustomerView(MasterView):
     model_class = model.Customer
     is_contact = True
     has_versions = True
+    results_downloadable = True
     people_detachable = True
     touchable = True
     supports_autocomplete = True
+    configurable = True
 
     # whether to show "view full profile" helper for customer view
     show_profiles_helper = True
@@ -92,6 +94,25 @@ class CustomerView(MasterView):
         'members',
     ]
 
+    mergeable = True
+
+    merge_coalesce_fields = [
+        'email_addresses',
+        'phone_numbers',
+    ]
+
+    merge_fields = merge_coalesce_fields + [
+        'uuid',
+        'name',
+    ]
+
+    def get_expose_active_in_pos(self):
+        if not hasattr(self, '_expose_active_in_pos'):
+            self._expose_active_in_pos = self.rattail_config.getbool(
+                'rattail', 'customers.active_in_pos',
+                default=False)
+        return self._expose_active_in_pos
+
     def configure_grid(self, g):
         super(CustomerView, self).configure_grid(g)
 
@@ -132,8 +153,9 @@ class CustomerView(MasterView):
         g.set_renderer('person', self.grid_render_person)
 
         # active_in_pos
-        g.filters['active_in_pos'].default_active = True
-        g.filters['active_in_pos'].default_verb = 'is_true'
+        if self.get_expose_active_in_pos():
+            g.filters['active_in_pos'].default_active = True
+            g.filters['active_in_pos'].default_verb = 'is_true'
 
         g.set_link('id')
         g.set_link('number')
@@ -142,8 +164,9 @@ class CustomerView(MasterView):
         g.set_link('email')
 
     def grid_extra_class(self, customer, i):
-        if not customer.active_in_pos:
-            return 'warning'
+        if self.get_expose_active_in_pos():
+            if not customer.active_in_pos:
+                return 'warning'
 
     def get_instance(self):
         try:
@@ -246,6 +269,10 @@ class CustomerView(MasterView):
         customer = f.model_instance
         permission_prefix = self.get_permission_prefix()
 
+        if not self.get_expose_active_in_pos():
+            f.remove('active_in_pos',
+                     'active_in_pos_sticky')
+
         # members
         if self.creating:
             f.remove_field('members')
@@ -430,6 +457,52 @@ class CustomerView(MasterView):
 
         return self.redirect(self.request.get_referrer())
 
+    def get_merge_data(self, customer):
+        return {
+            'uuid': customer.uuid,
+            'name': customer.name,
+            'email_addresses': [e.address for e in customer.emails],
+            'phone_numbers': [p.number for p in customer.phones],
+        }
+
+    def merge_objects(self, removing, keeping):
+        coalesce = self.get_merge_coalesce_fields()
+        if coalesce:
+
+            if 'email_addresses' in coalesce:
+                keeping_emails = [e.address for e in keeping.emails]
+                for email in removing.emails:
+                    if email.address not in keeping_emails:
+                        keeping.add_email(address=email.address,
+                                          type=email.type,
+                                          invalid=email.invalid)
+                        keeping_emails.append(email.address)
+
+            if 'phone_numbers' in coalesce:
+                keeping_phones = [e.number for e in keeping.phones]
+                for phone in removing.phones:
+                    if phone.number not in keeping_phones:
+                        keeping.add_phone(number=phone.number,
+                                          type=phone.type)
+                        keeping_phones.append(phone.number)
+
+        self.Session.delete(removing)
+
+    def configure_get_simple_settings(self):
+        return [
+
+            # General
+            {'section': 'rattail',
+             'option': 'customers.choice_uses_dropdown',
+             'type': bool},
+
+            # POS
+            {'section': 'rattail',
+             'option': 'customers.active_in_pos',
+             'type': bool},
+
+        ]
+
     @classmethod
     def defaults(cls, config):
         cls._defaults(config)
