@@ -52,6 +52,7 @@ class CustomerOrderItemView(MasterView):
     deletable = False
 
     labels = {
+        'order': "Customer Order",
         'order_id': "Order ID",
         'order_uom': "Order UOM",
         'status_code': "Status",
@@ -90,6 +91,7 @@ class CustomerOrderItemView(MasterView):
         'sequence',
         'person',
         'product',
+        'pending_product',
         'product_brand',
         'product_description',
         'product_size',
@@ -171,18 +173,37 @@ class CustomerOrderItemView(MasterView):
     def configure_form(self, f):
         super(CustomerOrderItemView, self).configure_form(f)
         use_buefy = self.get_use_buefy()
+        item = f.model_instance
 
         # order
         f.set_renderer('order', self.render_order)
 
-        # product
+        # (pending) product
         f.set_renderer('product', self.render_product)
+        f.set_renderer('pending_product', self.render_pending_product)
+        if self.viewing:
+            if item.product and not item.pending_product:
+                f.remove('pending_product')
+            elif item.pending_product and not item.product:
+                f.remove('product')
 
         # product uom
         f.set_enum('product_unit_of_measure', self.enum.UNIT_OF_MEASURE)
 
+        # highlight pending fields
+        f.set_renderer('product_brand', self.highlight_pending_field)
+        f.set_renderer('product_description', self.highlight_pending_field)
+        f.set_renderer('product_size', self.highlight_pending_field)
+        f.set_renderer('case_quantity', self.highlight_pending_field_quantity)
+
+        'unit_price',
+        'total_price',
+        'price_needs_confirmation',
+        'paid_amount',
+        'status_code',
+        'notes',
+
         # quantity fields
-        f.set_type('case_quantity', 'quantity')
         f.set_type('cases_ordered', 'quantity')
         f.set_type('units_ordered', 'quantity')
         f.set_type('order_quantity', 'quantity')
@@ -206,10 +227,27 @@ class CustomerOrderItemView(MasterView):
         else:
             f.remove('notes')
 
+    def highlight_pending_field(self, item, field, value=None):
+        if value is None:
+            value = getattr(item, field)
+        if not item.product_uuid and item.pending_product_uuid:
+            return HTML.tag('span', c=[value],
+                            class_='has-text-success')
+        return value
+
+    def highlight_pending_field_quantity(self, item, field):
+        app = self.get_rattail_app()
+        value = getattr(item, field)
+        value = app.render_quantity(value)
+        return self.highlight_pending_field(item, field, value)
+
     def render_price_with_confirmation(self, item, field):
         price = getattr(item, field)
         app = self.get_rattail_app()
         text = app.render_currency(price)
+        if not item.product_uuid and item.pending_product_uuid:
+            text = HTML.tag('span', c=[text],
+                            class_='has-text-success')
         if item.price_needs_confirmation:
             return HTML.tag('span', class_='has-background-warning',
                             c=[text])
