@@ -27,12 +27,13 @@ Customer Order Views
 from __future__ import unicode_literals, absolute_import
 
 import decimal
+import logging
 
 import six
 from sqlalchemy import orm
 
 from rattail.db import model
-from rattail.util import pretty_quantity
+from rattail.util import pretty_quantity, simple_error
 from rattail.batch import get_batch_handler
 
 from webhelpers2.html import tags, HTML
@@ -41,6 +42,9 @@ from tailbone.db import Session
 from tailbone.views import MasterView
 
 
+log = logging.getLogger(__name__)
+
+
 class CustomerOrderView(MasterView):
     """
     Master view for customer orders
@@ -335,7 +339,6 @@ class CustomerOrderView(MasterView):
             'batch': batch,
             'normalized_batch': self.normalize_batch(batch),
             'new_order_requires_customer': self.batch_handler.new_order_requires_customer(),
-            'product_key_field': self.rattail_config.product_key(),
             'product_price_may_be_questionable': self.batch_handler.product_price_may_be_questionable(),
             'allow_contact_info_choice': self.batch_handler.allow_contact_info_choice(),
             'allow_contact_info_create': self.batch_handler.allow_contact_info_creation(),
@@ -343,8 +346,15 @@ class CustomerOrderView(MasterView):
             'product_key_label': self.rattail_config.product_key_title(),
             'allow_unknown_product': self.batch_handler.allow_unknown_product(),
             'department_options': self.get_department_options(),
+            'default_uom_choices': self.batch_handler.uom_choices_for_product(None),
+            'default_uom': None,
         })
 
+        if self.batch_handler.allow_case_orders():
+            context['default_uom'] = self.enum.UNIT_OF_MEASURE_CASE
+        elif self.batch_handler.allow_unit_orders():
+            context['default_uom'] = self.enum.UNIT_OF_MEASURE_EACH
+
         return self.render_to_response(template, context)
 
     def get_department_options(self):
@@ -908,7 +918,9 @@ class CustomerOrderView(MasterView):
         try:
             result = self.execute_new_order_batch(batch, data)
         except Exception as error:
-            return {'error': six.text_type(error)}
+            log.warning("failed to execute new order batch: %s", batch,
+                        exc_info=True)
+            return {'error': simple_error(error)}
         else:
             if not result:
                 return {'error': "Batch failed to execute"}
@@ -938,11 +950,17 @@ class CustomerOrderView(MasterView):
 
             # product handling
             {'section': 'rattail.custorders',
-             'option': 'allow_unknown_product',
+             'option': 'allow_case_orders',
+             'type': bool},
+            {'section': 'rattail.custorders',
+             'option': 'allow_unit_orders',
              'type': bool},
             {'section': 'rattail.custorders',
              'option': 'product_price_may_be_questionable',
              'type': bool},
+            {'section': 'rattail.custorders',
+             'option': 'allow_unknown_product',
+             'type': bool},
         ]
 
     @classmethod
