@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2021 Lance Edgar
+#  Copyright © 2010-2022 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -39,6 +39,7 @@ class FamilyView(MasterView):
     model_title_plural = "Families"
     route_prefix = 'families'
     has_versions = True
+    results_downloadable = True
     grid_key = 'families'
 
     grid_columns = [
@@ -54,12 +55,8 @@ class FamilyView(MasterView):
     has_rows = True
     model_row_class = model.Product
 
-    row_labels = {
-        'upc': "UPC",
-    }
-
     row_grid_columns = [
-        'upc',
+        '_product_key_',
         'brand',
         'description',
         'size',
@@ -94,7 +91,9 @@ class FamilyView(MasterView):
         g.set_renderer('regular_price', self.render_price)
         g.set_renderer('current_price', self.render_price)
 
-        g.set_sort_defaults('upc')
+        key = self.rattail_config.product_key()
+        field = self.product_key_fields.get(key, key)
+        g.set_sort_defaults(field)
 
     def render_price(self, product, field):
         if not product.not_for_sale:
