@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2021 Lance Edgar
+#  Copyright © 2010-2022 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -1470,7 +1470,18 @@ class MergePeopleRequestView(MasterView):
         return "(person not found)"
 
 
-def includeme(config):
+def defaults(config, **kwargs):
+    base = globals()
+
+    PersonView = kwargs.get('PersonView', base['PersonView'])
     PersonView.defaults(config)
+
+    PersonNoteView = kwargs.get('PersonNoteView', base['PersonNoteView'])
     PersonNoteView.defaults(config)
+
+    MergePeopleRequestView = kwargs.get('MergePeopleRequestView', base['MergePeopleRequestView'])
     MergePeopleRequestView.defaults(config)
+
+
+def includeme(config):
+    defaults(config)
