@@ -225,6 +225,7 @@ class ProductView(MasterView):
     def configure_grid(self, g):
         super(ProductView, self).configure_grid(g)
         app = self.get_rattail_app()
+        model = self.model
         use_buefy = self.get_use_buefy()
 
         def join_vendor(q):
@@ -335,8 +336,16 @@ class ProductView(MasterView):
         g.set_label('vendor_code_any', "Vendor Code (any)")
 
         # category
-        g.set_joiner('category', lambda q: q.outerjoin(model.Category))
-        g.set_filter('category', model.Category.name)
+        CategoryByCode = orm.aliased(model.Category)
+        CategoryByName = orm.aliased(model.Category)
+        g.set_joiner('category_code',
+                     lambda q: q.outerjoin(CategoryByCode,
+                                           CategoryByCode.uuid == model.Product.category_uuid))
+        g.set_filter('category_code', CategoryByCode.code)
+        g.set_joiner('category_name',
+                     lambda q: q.outerjoin(CategoryByName,
+                                           CategoryByName.uuid == model.Product.category_uuid))
+        g.set_filter('category_name', CategoryByName.name)
 
         # family
         g.set_joiner('family', lambda q: q.outerjoin(model.Family))
@@ -900,7 +909,7 @@ class ProductView(MasterView):
                 f.set_label('family_uuid', "Family")
         else:
             f.set_readonly('family')
-            # f.set_renderer('family', self.render_family)
+            f.set_renderer('family', self.render_family)
 
         # report_code
         if self.creating or self.editing:
@@ -1180,9 +1189,6 @@ class ProductView(MasterView):
         product = kwargs['instance']
         use_buefy = self.get_use_buefy()
 
-        key = self.rattail_config.product_key()
-        kwargs['product_key_field'] = self.product_key_fields.get(key, key)
-
         kwargs['image_url'] = self.products_handler.get_image_url(product)
 
         # add price history, if user has access
@@ -1892,14 +1898,15 @@ class ProductView(MasterView):
         return {'product': data}
 
     def get_supported_batches(self):
+        app = self.get_rattail_app()
+        pricing = app.get_batch_handler('pricing')
         return OrderedDict([
             ('labels', {
                 'spec': self.rattail_config.get('rattail.batch', 'labels.handler',
                                                 default='rattail.batch.labels:LabelBatchHandler'),
             }),
             ('pricing', {
-                'spec': self.rattail_config.get('rattail.batch', 'pricing.handler',
-                                                default='rattail.batch.pricing:PricingBatchHandler'),
+                'spec': pricing.get_spec(),
             }),
             ('delproduct', {
                 'spec': self.rattail_config.get('rattail.batch', 'delproduct.handler',
@@ -2003,7 +2010,9 @@ class ProductView(MasterView):
         """
         Return params schema for making a pricing batch.
         """
-        return colander.SchemaNode(
+        app = self.get_rattail_app()
+
+        schema = colander.SchemaNode(
             colander.Mapping(),
             colander.SchemaNode(colander.Decimal(), name='min_diff_threshold',
                                 quant='1.00', missing=colander.null,
@@ -2014,6 +2023,17 @@ class ProductView(MasterView):
             colander.SchemaNode(colander.Boolean(), name='calculate_for_manual'),
         )
 
+        pricing = app.get_batch_handler('pricing')
+        if pricing.allow_future():
+            schema.insert(0, colander.SchemaNode(
+                colander.Date(),
+                name='start_date',
+                missing=colander.null,
+                title="Start Date (FUTURE only)",
+                widget=forms.widgets.JQueryDateWidget()))
+
+        return schema
+
     def make_batch_params_schema_delproduct(self):
         """
         Return params schema for making a "delete products" batch.
