@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2017 Lance Edgar
+#  Copyright © 2010-2020 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -26,18 +26,31 @@ Progress Views
 
 from __future__ import unicode_literals, absolute_import
 
+import six
+
 from tailbone.progress import get_progress_session
 
 
 def progress(request):
     key = request.matchdict['key']
-    session = get_progress_session(request, key, type=request.GET.get('sessiontype'))
+    session = get_progress_session(request, key,
+                                   type=request.GET.get('sessiontype'))
+
     if session.get('complete'):
+
         msg = session.get('success_msg')
         if msg:
             request.session.flash(msg)
+
+        bits = session.get('extra_session_bits')
+        if bits:
+            for key, value in six.iteritems(bits):
+                request.session[key] = value
+
     elif session.get('error'):
-        request.session.flash(session.get('error_msg', "An unspecified error occurred."), 'error')
+        msg = session.get('error_msg', "An unspecified error occurred.")
+        request.session.flash(msg, 'error')
+
     return session
 
 
