@@ -49,6 +49,7 @@ class PurchasingBatchView(BatchMasterView):
     default_handler_spec = 'rattail.batch.purchase:PurchaseBatchHandler'
     supports_new_product = False
     cloneable = True
+    default_help_url = 'https://rattailproject.org/docs/rattail-manual/features/purchasing/receiving/index.html'
 
     labels = {
         'po_total': "PO Total",
@@ -179,10 +180,9 @@ class PurchasingBatchView(BatchMasterView):
         g.filters['department'] = g.make_filter('department', model.Department.name)
         g.sorters['department'] = g.make_sorter(model.Department.name)
 
-        g.joiners['buyer'] = lambda q: q.join(model.Employee).join(model.Person)
-        g.filters['buyer'] = g.make_filter('buyer', model.Person.display_name,
-                                           default_active=True, default_verb='contains')
-        g.sorters['buyer'] = g.make_sorter(model.Person.display_name)
+        g.set_joiner('buyer', lambda q: q.join(model.Employee).join(model.Person))
+        g.set_filter('buyer', model.Person.display_name)
+        g.set_sorter('buyer', model.Person.display_name)
 
         # TODO: we used to include the 'complete' filter by default, but it
         # seems to likely be confusing for newcomers, so it is no longer
@@ -405,6 +405,12 @@ class PurchasingBatchView(BatchMasterView):
                             'vendor_contact',
                             'status_code')
 
+    def valid_vendor_uuid(self, node, value):
+        model = self.model
+        vendor = self.Session.query(model.Vendor).get(value)
+        if not vendor:
+            raise colander.Invalid(node, "Invalid vendor selection")
+
     def render_store(self, batch, field):
         store = batch.store
         if not store:
@@ -797,7 +803,9 @@ class PurchasingBatchView(BatchMasterView):
         app = self.get_rattail_app()
         cases = getattr(row, 'cases_{}'.format(field))
         units = getattr(row, 'units_{}'.format(field))
-        return app.render_cases_units(cases, units)
+        # nb. do not render anything if empty quantities
+        if cases or units:
+            return app.render_cases_units(cases, units)
 
     def make_row_credits_grid(self, row):
         use_buefy = self.get_use_buefy()
@@ -809,8 +817,6 @@ class PurchasingBatchView(BatchMasterView):
             data=[] if use_buefy else row.credits,
             columns=[
                 'credit_type',
-                # 'cases_shorted',
-                # 'units_shorted',
                 'shorted',
                 'credit_total',
                 'expiration_date',
@@ -821,20 +827,19 @@ class PurchasingBatchView(BatchMasterView):
             ],
             labels={
                 'credit_type': "Type",
-                'cases_shorted': "Cases",
-                'units_shorted': "Units",
                 'shorted': "Quantity",
                 'credit_total': "Total",
-                'mispick_upc': "Mispick UPC",
-                'mispick_brand_name': "MP Brand",
-                'mispick_description': "MP Description",
-                'mispick_size': "MP Size",
+                # 'mispick_upc': "Mispick UPC",
+                # 'mispick_brand_name': "MP Brand",
+                # 'mispick_description': "MP Description",
+                # 'mispick_size': "MP Size",
             })
 
-        g.set_type('cases_shorted', 'quantity')
-        g.set_type('units_shorted', 'quantity')
         g.set_type('credit_total', 'currency')
 
+        if not self.batch_handler.allow_expired_credits():
+            g.remove('expiration_date')
+
         return g
 
     def render_row_credits(self, row, field):
