@@ -115,7 +115,6 @@ class ReceivingBatchView(PurchasingBatchView):
         'store',
         'vendor',
         'receiving_workflow',
-        'description',
         'truck_dump',
         'truck_dump_children_first',
         'truck_dump_children',
@@ -130,13 +129,14 @@ class ReceivingBatchView(PurchasingBatchView):
         'vendor_contact',
         'vendor_phone',
         'date_ordered',
-        'date_received',
         'po_number',
         'po_total',
+        'date_received',
         'invoice_date',
         'invoice_number',
         'invoice_total',
         'invoice_total_calculated',
+        'description',
         'notes',
         'created',
         'created_by',
@@ -152,8 +152,7 @@ class ReceivingBatchView(PurchasingBatchView):
 
     row_grid_columns = [
         'sequence',
-        'upc',
-        # 'item_id',
+        '_product_key_',
         'vendor_code',
         'brand_name',
         'description',
@@ -177,8 +176,7 @@ class ReceivingBatchView(PurchasingBatchView):
     row_form_fields = [
         'sequence',
         'item_entry',
-        'upc',
-        'item_id',
+        '_product_key_',
         'vendor_code',
         'product',
         'brand_name',
@@ -266,6 +264,8 @@ class ReceivingBatchView(PurchasingBatchView):
         # least will not need customization for that.
         if self.request.matched_route.name.endswith('create_workflow'):
 
+            redirect = self.redirect(self.request.route_url('{}.create'.format(route_prefix)))
+
             # however we do have one more thing to check - the workflow
             # requested must of course be valid!
             workflow_key = self.request.matchdict['workflow_key']
@@ -273,7 +273,18 @@ class ReceivingBatchView(PurchasingBatchView):
                 self.request.session.flash(
                     "Not a supported workflow: {}".format(workflow_key),
                     'error')
-                raise self.redirect(self.request.route_url('{}.create'.format(route_prefix)))
+                raise redirect
+
+            # also, we require vendor to be correctly identified.  if
+            # someone e.g. navigates to a URL by accident etc. we want
+            # to gracefully handle and redirect
+            uuid = self.request.matchdict['vendor_uuid']
+            vendor = self.Session.query(model.Vendor).get(uuid)
+            if not vendor:
+                self.request.session.flash("Invalid vendor selection.  "
+                                           "Please choose an existing vendor.",
+                                           'warning')
+                raise redirect
 
             # okay now do the normal thing, per workflow
             return super(ReceivingBatchView, self).create(**kwargs)
@@ -298,26 +309,48 @@ class ReceivingBatchView(PurchasingBatchView):
         # configure vendor field
         app = self.get_rattail_app()
         vendor_handler = app.get_vendor_handler()
-        use_dropdown = vendor_handler.choice_uses_dropdown()
-        if use_dropdown:
-            vendors = self.Session.query(model.Vendor)\
-                                  .order_by(model.Vendor.id)
-            vendor_values = [(vendor.uuid, "({}) {}".format(vendor.id, vendor.name))
+        if self.rattail_config.getbool('rattail.batch', 'purchase.supported_vendors_only'):
+            # only show vendors for which we have dedicated invoice parsers
+            vendors = {}
+            for parser in self.batch_handler.get_supported_invoice_parsers():
+                if parser.vendor_key:
+                    vendor = vendor_handler.get_vendor(self.Session(),
+                                                       parser.vendor_key)
+                    if vendor:
+                        vendors[vendor.uuid] = vendor
+            vendors = sorted(vendors.values(), key=lambda v: v.name)
+            vendor_values = [(vendor.uuid, vendor_handler.render_vendor(vendor))
                              for vendor in vendors]
             if use_buefy:
                 form.set_widget('vendor', dfwidget.SelectWidget(values=vendor_values))
             else:
                 form.set_widget('vendor', forms.widgets.JQuerySelectWidget(values=vendor_values))
         else:
-            vendor_display = ""
-            if self.request.method == 'POST':
-                if self.request.POST.get('vendor'):
-                    vendor = self.Session.query(model.Vendor).get(self.request.POST['vendor'])
-                    if vendor:
-                        vendor_display = six.text_type(vendor)
-            vendors_url = self.request.route_url('vendors.autocomplete')
-            form.set_widget('vendor', forms.widgets.JQueryAutocompleteWidget(
-                field_display=vendor_display, service_url=vendors_url))
+            # user may choose *any* available vendor
+            use_dropdown = vendor_handler.choice_uses_dropdown()
+            if use_dropdown:
+                vendors = self.Session.query(model.Vendor)\
+                                      .order_by(model.Vendor.id)\
+                                      .all()
+                vendor_values = [(vendor.uuid, "({}) {}".format(vendor.id, vendor.name))
+                                 for vendor in vendors]
+                if use_buefy:
+                    form.set_widget('vendor', dfwidget.SelectWidget(values=vendor_values))
+                else:
+                    form.set_widget('vendor', forms.widgets.JQuerySelectWidget(values=vendor_values))
+                if len(vendors) == 1:
+                    form.set_default('vendor', vendors[0].uuid)
+            else:
+                vendor_display = ""
+                if self.request.method == 'POST':
+                    if self.request.POST.get('vendor'):
+                        vendor = self.Session.query(model.Vendor).get(self.request.POST['vendor'])
+                        if vendor:
+                            vendor_display = six.text_type(vendor)
+                vendors_url = self.request.route_url('vendors.autocomplete')
+                form.set_widget('vendor', forms.widgets.JQueryAutocompleteWidget(
+                    field_display=vendor_display, service_url=vendors_url))
+        form.set_validator('vendor', self.valid_vendor_uuid)
 
         # configure workflow field
         values = [(workflow['workflow_key'], workflow['display'])
@@ -504,7 +537,7 @@ class ReceivingBatchView(PurchasingBatchView):
                 f.set_widget('purchase_uuid', dfwidget.SelectWidget(values=values))
                 f.set_label('purchase_uuid', "Purchase Order")
                 f.set_required('purchase_uuid')
-        else:
+        elif self.creating or not batch.purchase:
             f.remove_field('purchase')
 
         # department
@@ -734,6 +767,8 @@ class ReceivingBatchView(PurchasingBatchView):
         products_handler = app.get_products_handler()
         row = kwargs['instance']
 
+        kwargs['allow_cases'] = self.batch_handler.allow_cases()
+
         if row.product:
             kwargs['image_url'] = products_handler.get_image_url(row.product)
         elif row.upc:
@@ -741,8 +776,16 @@ class ReceivingBatchView(PurchasingBatchView):
 
         if use_buefy:
             kwargs['row_context'] = self.get_context_row(row)
-            kwargs['possible_receiving_modes'] = POSSIBLE_RECEIVING_MODES
-            kwargs['possible_credit_types'] = POSSIBLE_CREDIT_TYPES
+
+            modes = list(POSSIBLE_RECEIVING_MODES)
+            types = list(POSSIBLE_CREDIT_TYPES)
+            if not self.batch_handler.allow_expired_credits():
+                if 'expired' in modes:
+                    modes.remove('expired')
+                if 'expired' in types:
+                    types.remove('expired')
+            kwargs['possible_receiving_modes'] = modes
+            kwargs['possible_credit_types'] = types
 
         return kwargs
 
@@ -1789,22 +1832,7 @@ class ReceivingBatchView(PurchasingBatchView):
             return pod.get_image_url(self.rattail_config, row.upc)
 
     def can_auto_receive(self, batch):
-        if batch.executed:
-            return False
-        if batch.complete:
-            return False
-
-        if batch.is_truck_dump_related():
-            if not batch.is_truck_dump_parent():
-                return False
-            if not batch.truck_dump_children_first():
-                return False
-
-        # only auto-receive once per batch
-        if batch.get_param('auto_received'):
-            return False
-
-        return True
+        return self.handler.can_auto_receive(batch)
 
     def auto_receive(self):
         """
@@ -1830,7 +1858,7 @@ class ReceivingBatchView(PurchasingBatchView):
         """
         session = RattailSession()
         batch = session.query(model.PurchaseBatch).get(uuid)
-        user = session.query(model.User).get(user_uuid)
+        # user = session.query(model.User).get(user_uuid)
         try:
             self.handler.auto_receive_all_items(batch, progress=progress)
 
@@ -1862,7 +1890,7 @@ class ReceivingBatchView(PurchasingBatchView):
         config = self.rattail_config
         return [
 
-            # supported workflows
+            # workflows
             {'section': 'rattail.batch',
              'option': 'purchase.allow_receiving_from_scratch',
              'type': bool},
@@ -1879,6 +1907,11 @@ class ReceivingBatchView(PurchasingBatchView):
              'option': 'purchase.allow_truck_dump_receiving',
              'type': bool},
 
+            # vendors
+            {'section': 'rattail.batch',
+             'option': 'purchase.supported_vendors_only',
+             'type': bool},
+
             # display
             {'section': 'rattail.batch',
              'option': 'purchase.receiving.show_ordered_column_in_grid',
