@@ -375,7 +375,7 @@ class ReportOutputView(ExportMasterView):
                                          for r in reports.values()]),
             'use_form': self.rattail_config.getbool(
                 'tailbone', 'reporting.choosing_uses_form',
-                default=True),
+                default=False),
         })
 
     def generate(self):
@@ -387,6 +387,8 @@ class ReportOutputView(ExportMasterView):
         use_buefy = self.get_use_buefy()
         type_key = self.request.matchdict['type_key']
         report = self.report_handler.get_report(type_key)
+        if not report:
+            return self.notfound()
         report_params = report.make_params(Session())
         route_prefix = self.get_route_prefix()
 
@@ -625,6 +627,8 @@ class ProblemReportView(MasterView):
 
         g.set_renderer('email_recipients', self.render_email_recipients)
 
+        g.set_searchable('problem_title')
+
         g.set_link('problem_key')
         g.set_link('problem_title')
 
@@ -652,18 +656,6 @@ class ProblemReportView(MasterView):
         f.set_renderer('email_key', self.render_email_key)
         f.set_renderer('email_recipients', self.render_email_recipients)
 
-    def render_email_key(self, report_info, field):
-        email_key = report_info[field]
-        if not email_key:
-            return
-
-        if self.request.has_perm('emailprofiles.view'):
-            text = email_key
-            url = self.request.route_url('emailprofiles.view', key=email_key)
-            return tags.link_to(text, url)
-
-        return email_key
-
     def render_email_recipients(self, report_info, field):
         recips = report_info['email_recipients']
         return ', '.join(recips)
