@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2021 Lance Edgar
+#  Copyright © 2010-2022 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -37,7 +37,9 @@ class SubdepartmentView(MasterView):
     Master view for the Subdepartment class.
     """
     model_class = model.Subdepartment
+    supports_autocomplete = True
     touchable = True
+    results_downloadable = True
     has_versions = True
 
     grid_columns = [
