@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2020 Lance Edgar
+#  Copyright © 2010-2022 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -155,6 +155,7 @@ class UpgradeView(MasterView):
 
     def configure_form(self, f):
         super(UpgradeView, self).configure_form(f)
+        upgrade = f.model_instance
 
         # status_code
         if self.creating:
@@ -168,7 +169,6 @@ class UpgradeView(MasterView):
             f.remove('executing')
 
         f.set_type('created', 'datetime')
-        f.set_type('enabled', 'boolean')
         f.set_type('executed', 'datetime')
         # f.set_widget('not_until', dfwidget.DateInputWidget())
         f.set_widget('notes', dfwidget.TextAreaWidget(cols=80, rows=8))
@@ -179,7 +179,6 @@ class UpgradeView(MasterView):
         # f.set_readonly('created_by')
         f.set_readonly('executed')
         f.set_readonly('executed_by')
-        upgrade = f.model_instance
         if self.creating or self.editing:
             f.remove_field('created')
             f.remove_field('created_by')
@@ -188,18 +187,20 @@ class UpgradeView(MasterView):
             if self.creating or not upgrade.executed:
                 f.remove_field('executed')
                 f.remove_field('executed_by')
-            if self.editing and upgrade.executed:
-                f.remove_field('enabled')
 
-        elif f.model_instance.executed:
-            f.remove_field('enabled')
-
-        else:
+        elif not upgrade.executed:
             f.remove_field('executed')
             f.remove_field('executed_by')
             f.remove_field('stdout_file')
             f.remove_field('stderr_file')
 
+        # enabled
+        if not self.creating and upgrade.executed:
+            f.remove('enabled')
+        else:
+            f.set_type('enabled', 'boolean')
+            f.set_default('enabled', True)
+
         if not self.viewing or not upgrade.executed:
             f.remove_field('package_diff')
             f.remove_field('exit_code')
@@ -416,6 +417,8 @@ class UpgradeView(MasterView):
         self.handler.mark_executing(upgrade)
         session.commit()
         self.handler.do_execute(upgrade, user, **kwargs)
+        return ("Execution has finished, for better or worse.  "
+                "You may need to restart your web app.")
 
     def execute_progress(self):
         upgrade = self.get_instance()
@@ -462,5 +465,12 @@ class UpgradeView(MasterView):
         cls._defaults(config)
 
 
-def includeme(config):
+def defaults(config, **kwargs):
+    base = globals()
+
+    UpgradeView = kwargs.get('UpgradeView', base['UpgradeView'])
     UpgradeView.defaults(config)
+
+
+def includeme(config):
+    defaults(config)
