@@ -69,6 +69,7 @@ class UserView(PrincipalMasterView):
         'active_sticky',
         'set_password',
         'roles',
+        'permissions',
     ]
 
     row_grid_columns = [
@@ -256,11 +257,12 @@ class UserView(PrincipalMasterView):
 
         if self.viewing:
             permissions = self.request.registry.settings.get('tailbone_permissions', {})
-            f.append('permissions')
             f.set_renderer('permissions', PermissionsRenderer(request=self.request,
                                                               permissions=permissions,
                                                               include_guest=True,
                                                               include_authenticated=True))
+        else:
+            f.remove('permissions')
 
         if self.viewing or self.deleting:
             f.remove('set_password')
@@ -384,7 +386,7 @@ class UserView(PrincipalMasterView):
         return six.text_type(name)
 
     def render_roles(self, user, field):
-        roles = user.roles
+        roles = sorted(user.roles, key=lambda r: r.name)
         items = []
         for role in roles:
             text = role.name
