@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2018 Lance Edgar
+#  Copyright © 2010-2022 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -45,5 +45,5 @@ def release(ctx, skip_tests=False):
         ctx.run('tox')
 
     shutil.rmtree('Tailbone.egg-info')
-    ctx.run('python setup.py sdist --formats=gztar')
+    ctx.run('python -m build --sdist')
     ctx.run('twine upload dist/Tailbone-{}.tar.gz'.format(__version__))
